@@ -270,7 +270,7 @@ let rec unfold f u () =
   match f u with
   | None -> return_nil
   | Some (x, u') -> Lwt.return (Cons (x, unfold f u'))
-  | exception exc when Lwt.Exception_filter.run exc -> Lwt.fail exc
+  | exception exc when Lwt.Exception_filter.run exc -> Lwt.reraise exc
 
 let rec unfold_lwt f u () =
   let* x = f u in
@@ -283,29 +283,23 @@ let unfold_lwt f u () =
   | None -> return_nil
   | Some (x, u') -> Lwt.return (Cons (x, unfold_lwt f u'))
 
-let rec of_list = function
-  | [] -> empty
-  | h :: t -> cons h (of_list t)
+let rec of_list l () =
+  Lwt.return (match l with [] -> Nil | h :: t -> Cons (h, of_list t))
 
-let rec to_list seq =
-  seq () >>= function
-  | Nil -> Lwt.return_nil
-  | Cons (x, next) ->
-    let+ l = to_list next in
-    x :: l
-let to_list seq =
-  Lwt.apply seq () >>= function
-  | Nil -> Lwt.return_nil
-  | Cons (x, next) ->
-    let+ l = to_list next in
-    x :: l
+let to_list (seq : 'a t) =
+  let rec aux f seq =
+    Lwt.bind (seq ()) (function
+      | Nil -> Lwt.return (f [])
+      | Cons (h, t) -> aux (fun x -> f (h :: x)) t)
+  in
+  aux (fun x -> x) (Lwt.apply seq)
 
 let rec of_seq seq () =
   match seq () with
   | Seq.Nil -> return_nil
   | Seq.Cons (x, next) ->
     Lwt.return (Cons (x, (of_seq next)))
-  | exception exn when Lwt.Exception_filter.run exn -> Lwt.fail exn
+  | exception exn when Lwt.Exception_filter.run exn -> Lwt.reraise exn
 
 let rec of_seq_lwt (seq: 'a Lwt.t Seq.t): 'a t = fun () ->
     match seq () with
@@ -321,4 +315,4 @@ let of_seq_lwt (seq: 'a Lwt.t Seq.t): 'a t = fun () ->
        let+ x = x in
        let next = of_seq_lwt next in
        Cons (x, next)
-    | exception exc when Lwt.Exception_filter.run exc -> Lwt.fail exc
+    | exception exc when Lwt.Exception_filter.run exc -> Lwt.reraise exc
