@@ -39,6 +39,17 @@ let () = Lwt_main.run (main ())
       [Lwt_main.run] will raise [Failure]. This should be considered a logic
       error (i.e., code making such a call is inherently broken).
 
+      In addition, note that if you have set the exception filter to let runtime
+      exceptions bubble up (via
+      [Lwt.Exception_filter.(set handle_all_except_runtime)])
+      then Lwt does not attempt to catch exceptions thrown by the OCaml runtime.
+      Specifically, in this case, Lwt lets [Out_of_memory] and [Stack_overflow]
+      exceptions traverse all of its functions and bubble up to the caller of
+      [Lwt_main.run]. Moreover because these exceptions are left to traverse the
+      call stack, they leave the internal data-structures in an inconsistent
+      state. For this reason, calling [Lwt_main.run] again after such an
+      exception will raise [Failure].
+
       It is not safe to call [Lwt_main.run] in a function registered with
       [Stdlib.at_exit], use {!Lwt_main.at_exit} instead. *)
 
@@ -49,22 +60,19 @@ val yield : unit -> unit Lwt.t [@@deprecated "Use Lwt.pause instead"]
 
       @deprecated Since 5.5.0 [yield] is deprecated in favor of the more general
       {!Lwt.pause} in order to avoid discrepancies in resolution (see below) and
-      stay compatible with other execution environments such as js_of_ocaml.
+      stay compatible with other execution environments such as js_of_ocaml. *)
 
-      Currently, paused promises are resolved more frequently than yielded promises.
-      The difference is unintended but existing applications could depend on it.
-      Unifying the two pools of promises into one in the future would eliminate
-      possible discrepancies and simplify the code. *)
-
-val abandon_yielded_and_paused : unit -> unit
+val abandon_yielded_and_paused : unit -> unit [@@deprecated "Use Lwt.abandon_paused instead"]
 (** Causes promises created with {!Lwt.pause} and {!Lwt_main.yield} to remain
     forever pending.
 
-    [yield] is now deprecated in favor of the more general {!Lwt.pause}.
-    Once [yield] is phased out, this function will be deprecated as well.
+    (Note that [yield] is deprecated in favor of the more general {!Lwt.pause}.)
 
     This is meant for use with {!Lwt_unix.fork}, as a way to “abandon” more
-    promise chains that are pending in your process. *)
+    promise chains that are pending in your process.
+
+    @deprecated Since 5.7 [abandon_yielded_and_paused] is deprecated in favour
+    of [Lwt.abandon_paused]. *)
 
 
 
