@@ -14,11 +14,11 @@
 #include "unix_readv_writev_utils.h"
 
 CAMLprim value lwt_unix_send_msg(value val_fd, value val_n_iovs, value val_iovs,
-                                 value val_n_fds, value val_fds)
+                                 value val_n_fds, value val_fds, value val_dest)
 {
     int n_iovs = Int_val(val_n_iovs);
     struct iovec iovs[n_iovs];
     flatten_io_vectors(iovs, val_iovs, n_iovs, NULL, NULL);
-    return wrapper_send_msg(Int_val(val_fd), n_iovs, iovs, val_n_fds, val_fds);
+    return wrapper_send_msg(Int_val(val_fd), n_iovs, iovs, val_n_fds, val_fds, val_dest);
 }
 #endif
